"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KMSHelper = void 0;
const AWS = require("aws-sdk");
const uuid_1 = require("uuid");
const typescript_helper_functions_1 = require("typescript-helper-functions");
/**
 * KMS Helper
 */
class KMSHelper extends typescript_helper_functions_1.BaseClass {
    /**
     * Initializes new instance of KMSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.KMS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.KMS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.KMS(options);
    }
    /**
     * Decrypt KMS
     * @param encryptedValue {string} Value to decrypt
     */
    DecryptAsync(encryptedValue) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${KMSHelper.name}.${this.DecryptAsync.name}`;
            this.LogHelper.LogInputs(action, { cipherTextBlob: encryptedValue });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(encryptedValue)) {
                throw new Error(`[${action}]-Must supply encryptedValue`);
            }
            // create params object
            const params = {
                CiphertextBlob: encryptedValue,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.decrypt(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Encrypt KMS
     * @param unencryptedValue {string} Value to encrypt
     */
    EncryptAsync(unencryptedValue) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${KMSHelper.name}.${this.EncryptAsync.name}`;
            this.LogHelper.LogInputs(action, { cipherTextBlob: unencryptedValue });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(unencryptedValue)) {
                throw new Error(`[${action}]-Must supply unencryptedValue`);
            }
            // create params object
            const params = {
                KeyId: uuid_1.v4(),
                Plaintext: unencryptedValue,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.encrypt(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
}
exports.KMSHelper = KMSHelper;
//# sourceMappingURL=helper.js.map